@@ -7,7 +7,7 @@
 #' @inheritParams model_performance.lm
 #'
 #' @details The mean square error is the mean of the sum of squared residuals,
-#'   i.e. it measures the average of the squares of the errors. Less technicaly
+#'   i.e. it measures the average of the squares of the errors. Less technically
 #'   speaking, the mean square error can be considered as the variance of the
 #'   residuals, i.e. the variation in the outcome the model doesn't explain.
 #'   Lower values (closer to zero) indicate better fit.
@@ -18,17 +18,21 @@
 #' data(mtcars)
 #' m <- lm(mpg ~ hp + gear, data = mtcars)
 #' performance_mse(m)
-#'
 #' @importFrom insight print_color
 #' @importFrom stats residuals
 #' @export
 performance_mse <- function(model, verbose = TRUE) {
-  res <- tryCatch({
-    stats::residuals(model)
-  },
-  error = function(e) {
-    NULL
-  }
+  res <- tryCatch(
+    {
+      if (inherits(model, c("vgam", "vglm"))) {
+        model@residuals
+      } else {
+        stats::residuals(model)
+      }
+    },
+    error = function(e) {
+      NULL
+    }
   )
 
   if (is.null(res) || all(is.na(res))) {
@@ -42,4 +46,4 @@ performance_mse <- function(model, verbose = TRUE) {
 
 #' @rdname performance_mse
 #' @export
-mse <- performance_mse
\ No newline at end of file
+mse <- performance_mse
